==> YEAST_1.7.0.tar.gz: YEAST/man/YEASTGO2PROBE.Rd <==
\name{YEASTGO2PROBE}
\alias{YEASTGO2PROBE}
\title{Mappings between GO identifiers and probe identifiers
  representing genes that are directly associated with the GO ids}
\description{
  The Gene Ontology (GO) Consortium maintains a controlled vocabulary of
  defined terms to describe gene products. Each of the terms is assigned
  a GO id that can be associated with a group of
  genes. YEASTGO2PROBE maps each GO id to the probe identifiers
  representing genes that are associated with the GO ids  
}
\details{
  GO terminologies are presented as a directed acyclic graph with root
  nodes having more general terms than their children
  nodes. YEASTGO2PROBE only maps GO ids to probe ids associated with
  nodes specified by the GO ids but not their children nodes. The mapped
  probe ids are named vectors. Names of the vectors are the evidence
  codes indicating what kind of evidence is found to support the
  association between GO ids and genes.

  The evidence codes in use include: 
  
  IMP - inferred from mutant phenotype
  
  IGI - inferred from genetic interaction

  IPI - inferred from physical interaction  

  ISS - inferred from sequence similarity  

  IDA - inferred from direct assay  

  IEP - inferred from expression pattern  

  IEA - inferred from electronic annotation  

  TAS - traceable author statement  

  NAS - non-traceable author statement  

  ND - no biological data available  

  IC - inferred by curator
  
  A GO id may be mapped to the same probe id more than once but
  the evidence code can be different. Mappings between Gene Ontology ids
  an Gene Ontology terms and other information are available in a
  separate data package named GO. 
  
  Mappings were based on data provided by:

  LocusLink Yeast Genome:\url{http://www.yeastgenome.org/DownloadContents.shtml}. Built: Yeast Genome data are built at various time  intervals. Sources used were downloaded  Fri Jan  7 14:56:40 2005 
.

  Package built Fri Jan  7 16:12:38 2005
}
\references{
\url{ftp://ftp.ncbi.nih.gov/refseq/LocusLink/LL_tmpl.gz}
}
\examples{
    # Convert to a list
    xx <- as.list(YEASTGO2PROBE)
    if(length(xx) > 0){
        # Gets the probe ids for the top 2nd and 3nd GO ids
        goids <- xx[2:3]
        # Gets the probe ids for the first element of goids
        goids[[1]]
        # Evidence code for the mappings
        names(goids[[1]])
    }
}
\keyword{datasets}

==> YEAST_1.8.1.tar.gz: YEAST/man/YEASTGO2PROBE.Rd <==
\name{YEASTGO2PROBE}
\alias{YEASTGO2PROBE}
\title{Map Between Gene Ontology (GO) and Manufacturer Identifiers}
\description{
   YEASTGO2PROBE is an R environment that provides mappings between
   GO ids and manufacturer ids.
}
\details{
  Each GO term maps to a named vector of manufacturer ids. The name
  associated with each manufacturer id corresponds to the evidence code
  for that GO id. The evidence code indicates what kind of evidence
  supports the association between the GO and Entrez Gene ids. Evidence
  codes currently in use include:
  
  IMP - inferred from mutant phenotype
  
  IGI - inferred from genetic interaction

  IPI - inferred from physical interaction  

  ISS - inferred from sequence similarity  

  IDA - inferred from direct assay  

  IEP - inferred from expression pattern  

  IEA - inferred from electronic annotation  

  TAS - traceable author statement  

  NAS - non-traceable author statement  

  ND - no biological data available  

  IC - inferred by curator
  
  A GO id may be mapped to the same probe id more than once but
  the evidence code can be different. Mappings between Gene Ontology ids
  an Gene Ontology terms and other information are available in a
  separate data package named GO. 
  
  Mappings were based on data provided by:

  LocusLink Yeast Genome: Not available.

  Package built Tue May 17 18:17:12 2005
}
\references{
\url{ftp://ftp.ncbi.nlm.nih.gov/gene/DATA/}
}
\examples{
    # Convert to a list
    xx <- as.list(YEASTGO2PROBE)
    if(length(xx) > 0){
        # Gets the probe ids for the top 2nd and 3nd GO ids
        goids <- xx[2:3]
        # Gets the probe ids for the first element of goids
        goids[[1]]
        # Evidence code for the mappings
        names(goids[[1]])
    }
}
\keyword{datasets}
